==> estateplat-common-1.2.4-20210611.062106-790-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxGhxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;


/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0
 * @description 外网申请过户信息表
 */
@Table(name = "GX_WW_SQXX_GHXX")
public class GxWwSqxxGhxx {
    @Id
    private String ghxxid;
    private String sqxxid;
    private String ssfgh;
    private String dsfgh;
    private String qsfgh;
    private String gdsfgh;
    private String wlsfgh;
    private String yskkh;
    private String ydkkh;

    public String getGhxxid() {
        return ghxxid;
    }

    public void setGhxxid(String ghxxid) {
        this.ghxxid = ghxxid;
    }

    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getSsfgh() {
        return ssfgh;
    }

    public void setSsfgh(String ssfgh) {
        this.ssfgh = ssfgh;
    }

    public String getDsfgh() {
        return dsfgh;
    }

    public void setDsfgh(String dsfgh) {
        this.dsfgh = dsfgh;
    }

    public String getQsfgh() {
        return qsfgh;
    }

    public void setQsfgh(String qsfgh) {
        this.qsfgh = qsfgh;
    }

    public String getGdsfgh() {
        return gdsfgh;
    }

    public void setGdsfgh(String gdsfgh) {
        this.gdsfgh = gdsfgh;
    }

    public String getWlsfgh() {
        return wlsfgh;
    }

    public void setWlsfgh(String wlsfgh) {
        this.wlsfgh = wlsfgh;
    }

    public String getYskkh() {
        return yskkh;
    }

    public void setYskkh(String yskkh) {
        this.yskkh = yskkh;
    }

    public String getYdkkh() {
        return ydkkh;
    }

    public void setYdkkh(String ydkkh) {
        this.ydkkh = ydkkh;
    }
}

==> estateplat-common-1.2.4-20220611.095919-1037-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxGhxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;


/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0
 * @description 外网申请过户信息表
 */
@Table(name = "GX_WW_SQXX_GHXX")
public class GxWwSqxxGhxx {
    @Id
    private String ghxxid;
    private String sqxxid;
    private String ssfgh;
    private String dsfgh;
    private String qsfgh;
    private String gdsfgh;
    private String wlsfgh;
    private String yskkh;
    private String ydkkh;
    private String ygdkh;
    private String yrqkh;

    public String getGhxxid() {
        return ghxxid;
    }

    public void setGhxxid(String ghxxid) {
        this.ghxxid = ghxxid;
    }

    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getSsfgh() {
        return ssfgh;
    }

    public void setSsfgh(String ssfgh) {
        this.ssfgh = ssfgh;
    }

    public String getDsfgh() {
        return dsfgh;
    }

    public void setDsfgh(String dsfgh) {
        this.dsfgh = dsfgh;
    }

    public String getQsfgh() {
        return qsfgh;
    }

    public void setQsfgh(String qsfgh) {
        this.qsfgh = qsfgh;
    }

    public String getGdsfgh() {
        return gdsfgh;
    }

    public void setGdsfgh(String gdsfgh) {
        this.gdsfgh = gdsfgh;
    }

    public String getWlsfgh() {
        return wlsfgh;
    }

    public void setWlsfgh(String wlsfgh) {
        this.wlsfgh = wlsfgh;
    }

    public String getYskkh() {
        return yskkh;
    }

    public void setYskkh(String yskkh) {
        this.yskkh = yskkh;
    }

    public String getYdkkh() {
        return ydkkh;
    }

    public void setYdkkh(String ydkkh) {
        this.ydkkh = ydkkh;
    }

    public String getYgdkh() {
        return ygdkh;
    }

    public void setYgdkh(String ygdkh) {
        this.ygdkh = ygdkh;
    }

    public String getYrqkh() {
        return yrqkh;
    }

    public void setYrqkh(String yrqkh) {
        this.yrqkh = yrqkh;
    }
}
